#!/bin/bash

# define main function
MAIN_INSTALL="main_install"
MAIN_UPGRADE="main_upgrade"
MAIN_UNINST="main_uninst"
# define each page's name
PAGE_MARIADB5="page_mariadb5"
PAGE_MARIADB10="page_mariadb10"
PAGE_RESTORE="page_restore"
PAGE_UPGRADE_RESTRICTED="page_upgrade_restricted"
PAGE_DB="page_db"
PAGE_UNINST="page_uninst"
DEFAULT="enu"
# set out file name
OUTPUT_INSTALL="install_uifile"
OUTPUT_UPGRADE="upgrade_uifile"
OUTPUT_UNINST="uninstall_uifile"
INIT_DB_NAME="" # need to be overwrited
INIT_DB_USER="" # need to be overwrited
INFO_FILE="" # need to be overwrited
BACKUP_PATH="" # need to be overwrited
# here to define what page is necessary for each stage: install, upgrade, and uninstall
PAGES_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_MARIADB10 $PAGE_DB"
PAGES_UPGRADE="$PAGE_UPGRADE_RESTRICTED $PAGE_MARIADB5 $PAGE_MARIADB10 $PAGE_DB"
PAGES_UNINST="$PAGE_UNINST"
MIGRATE_DB_VERSION="-1"

MainCreate()
{
	local output="$1"
	local pages="$2"
	local main_function="$3"
	local lan
	for dir in lang/*; do
		lan=$(basename "$dir")
		cat "wizard_common" "wizard_customized" > "${output}_${lan}.sh"
		CustomWizCreate "${output}_${lan}.sh"
		cat "lang/$lan" $pages "$main_function" >> "${output}_${lan}.sh"
	done
	chmod +x "${output}"*.sh
	cp -a "${output}_${DEFAULT}.sh" "${output}.sh"
}

IsUpgradable()
{
	true
}

NeedMigrateMDB5()
{
	local prev_version="$1"
	if [ -z "$prev_version" ] || [ "$prev_version" -le "$MIGRATE_DB_VERSION" ]; then
		true
		return
	fi
	false
	return
}

CustomHasRunWebsiteSetup()
{
	local path="$1"
	[ -s "$path/$CONF_FILE" ]
}

CustomWizCreate()
{
	:
}

CustomSetBackupPath()
{
	BACKUP_PATH="$(CustomGetBackupPkgPath)"
}

CustomMainInstall()
{
	:
}

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_DIR.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}

GetPreviousPkgBuildNumber()
{
	local old_pkg_ver="$SYNOPKG_OLD_PKGVER"
	if [ -z "${old_pkg_ver}" ]; then
		# SYNOPKG_OLD_PKGVER does not exist in un-install stage of upgrade
		old_pkg_ver="$SYNOPKG_PKGVER"
	fi

	local old_build_number=$(echo "$old_pkg_ver" | cut -d- -f2)
	echo "$old_build_number"
}

CustomGetBackupPrefix()
{
	local backup_prefix="/$(readlink /var/services/web | cut -d/ -f2)/@appstore/.$PKG_DIR"
	echo "$backup_prefix"
}

CustomGetBackupPkgPath()
{
	local backup_pkg_path="$(CustomGetBackupPrefix)/$PKG_DIR"
	echo "$backup_pkg_path"
}

# we define pages in fuction not in global variables,
# because functions in wizard steps will be merged after calling MainCreate.
CustomSetPages()
{
	NEW_INSTALL_PAGES="$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageM10),$(PageDB)"
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageM10),$(PageDB)"
}

CustomParseDBConf()
{
	:
}

CustomGetDBName()
{
	:
}

CustomGetDBUser()
{
	:
}

CustomGetDBPass()
{
	:
}

CustomPageActivate()
{
	:
}

quote_json() {
	sed -e 's|\\|\\\\|g' -e 's|\"|\\\"|g'
}

#!/bin/bash
# Copyright (c) 2000-2017 Synology Inc. All rights reserved.

PKG_NAME="GLPI"
PKG_DIR="glpi"
WEBSITE_ROOT="/var/services/web/$PKG_DIR"
CONF_FILE="config/config_db.php"
MIGRATE_DB_VERSION="0112"
INIT_DB_NAME="glpi"
INIT_DB_USER="glpi_user"
INFO_FILE="/usr/syno/etc/packages/$PKG_NAME/$PKG_DIR.conf"

CustomParseDBConf()
{
	local path="$1"
	local db_info="$2"
	local grep_info="$3"
	local info_output=$(CustomGetValueFromMetaFile "$db_info")

	if [ -z "$info_output" ] && [ -s "$path/$CONF_FILE" ]; then
		info_output=$(grep "$grep_info" "$path/$CONF_FILE" | cut -d\' -f2)
	fi

	echo "$info_output"
}

CustomGetDBName()
{
	CustomParseDBConf "$1" "db_name" "dbdefault"
}

CustomGetDBUser()
{
	CustomParseDBConf "$1" "db_user" "dbuser"
}

CustomGetDBPass()
{
	CustomParseDBConf "$1" "db_pass" "dbpassword"
}
wizard_db_settings="GLPIデータベースをセットアップ"
wizard_db_name_desc="GLPI データベースの名前を入力してください。 "
wizard_db_name_label="データベース名"
wizard_m10_desc="MariaDB 10の管理者の資格情報を入力してからGLPIデータベース設定に進んでください。"
wizard_admin_acc="アカウント"
wizard_admin_pass="パスワード"
wizard_set_db_desc="新しい排他的データベースをGLPIに作成してから既存/新規のデータを使用してください。"
wizard_set_data_title="GLPIをセットアップ"
wizard_found_backup="パッケージは非互換性データを予約しました"
wizard_warn_data_backup_deprecated="システムのこのパッケージで予約されたデータはこのバージョンと互換性がありません。<br>このバージョンをインストールすると、予約されたデータは削除されます。<br>予約されたデータを保持したい場合、以前のインストールと同じバージョンのパッケージをインストールしてください。(以前のバージョン：{prev_version})"
wizard_db_user_account_desc="データベースのユーザー アカウント"
wizard_db_user_password_desc="データベース ユーザー パスワード"
wizard_migrate_note="GLPIの最新バージョンはMariaDB 10のみをサポートします。<br>システムが既存のMariaDB 5データベースを検出しました。<br>次のステップで、データベースはMariaDB 5からMariaDB 10に移行します。<br><br>MariaDB 5のadminの資格情報を入力してからインストールに進んでください。"
wizard_migrate_title="GLPIデータベースを移行"
wizard_remove_msql_title="GLPI データベースを削除"
wizard_remove_msql_desc="GLPI データベースを削除すると、すべてのデータが削除されます。"
wizard_msql_password_desc_remove="GLPI データベースを削除するには、データベースの管理者の認証情報を入力してください。"
wizard_admin_acc="アカウント"
wizard_admin_pass="パスワード"
wizard_unable_to_upgrade_title="このバージョンに更新できません"
wizard_upgrade_from_prev_release_required_desc="このバージョンへパッケージをアップデートする前に、その<a href=\"{1}\" target=\"_blank\">前のバージョン</a>にアップデートしてください。"
PageUninst()
{
cat << EOF
{
	"step_title": "$wizard_remove_msql_title",
	"items": [{
		"type": "multiselect",
		"subitems": [{
			"key": "pkgwizard_remove_mysql",
			"defaultValue": true,
			"hidden": true
		}]
	}, {
		"type": "textfield",
		"desc": "$wizard_msql_password_desc_remove",
		"subitems": [{
			"key": "wizard_m10_acc",
			"desc": "$wizard_admin_acc",
			"defaultValue": "root"
		}]
	}, {
		"type": "password",
		"subitems": [{
			"indent": 1,
			"key": "wizard_m10_pass",
			"desc": "$wizard_admin_pass"
		}]
	}]
}
EOF
}
main()
{
	local uninst_page="$(PageUninst)"
	echo "[$uninst_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
