#!/bin/bash

# define main function
MAIN_INSTALL="main_install"
MAIN_UPGRADE="main_upgrade"
MAIN_UNINST="main_uninst"
# define each page's name
PAGE_MARIADB5="page_mariadb5"
PAGE_MARIADB10="page_mariadb10"
PAGE_RESTORE="page_restore"
PAGE_UPGRADE_RESTRICTED="page_upgrade_restricted"
PAGE_DB="page_db"
PAGE_UNINST="page_uninst"
DEFAULT="enu"
# set out file name
OUTPUT_INSTALL="install_uifile"
OUTPUT_UPGRADE="upgrade_uifile"
OUTPUT_UNINST="uninstall_uifile"
INIT_DB_NAME="" # need to be overwrited
INIT_DB_USER="" # need to be overwrited
INFO_FILE="" # need to be overwrited
BACKUP_PATH="" # need to be overwrited
# here to define what page is necessary for each stage: install, upgrade, and uninstall
PAGES_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_MARIADB10 $PAGE_DB"
PAGES_UPGRADE="$PAGE_UPGRADE_RESTRICTED $PAGE_MARIADB5 $PAGE_MARIADB10 $PAGE_DB"
PAGES_UNINST="$PAGE_UNINST"
MIGRATE_DB_VERSION="-1"

MainCreate()
{
	local output="$1"
	local pages="$2"
	local main_function="$3"
	local lan
	for dir in lang/*; do
		lan=$(basename "$dir")
		cat "wizard_common" "wizard_customized" > "${output}_${lan}.sh"
		CustomWizCreate "${output}_${lan}.sh"
		cat "lang/$lan" $pages "$main_function" >> "${output}_${lan}.sh"
	done
	chmod +x "${output}"*.sh
	cp -a "${output}_${DEFAULT}.sh" "${output}.sh"
}

IsUpgradable()
{
	true
}

NeedMigrateMDB5()
{
	local prev_version="$1"
	if [ -z "$prev_version" ] || [ "$prev_version" -le "$MIGRATE_DB_VERSION" ]; then
		true
		return
	fi
	false
	return
}

CustomHasRunWebsiteSetup()
{
	local path="$1"
	[ -s "$path/$CONF_FILE" ]
}

CustomWizCreate()
{
	:
}

CustomSetBackupPath()
{
	BACKUP_PATH="$(CustomGetBackupPkgPath)"
}

CustomMainInstall()
{
	:
}

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_DIR.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}

GetPreviousPkgBuildNumber()
{
	local old_pkg_ver="$SYNOPKG_OLD_PKGVER"
	if [ -z "${old_pkg_ver}" ]; then
		# SYNOPKG_OLD_PKGVER does not exist in un-install stage of upgrade
		old_pkg_ver="$SYNOPKG_PKGVER"
	fi

	local old_build_number=$(echo "$old_pkg_ver" | cut -d- -f2)
	echo "$old_build_number"
}

CustomGetBackupPrefix()
{
	local backup_prefix="/$(readlink /var/services/web | cut -d/ -f2)/@appstore/.$PKG_DIR"
	echo "$backup_prefix"
}

CustomGetBackupPkgPath()
{
	local backup_pkg_path="$(CustomGetBackupPrefix)/$PKG_DIR"
	echo "$backup_pkg_path"
}

# we define pages in fuction not in global variables,
# because functions in wizard steps will be merged after calling MainCreate.
CustomSetPages()
{
	NEW_INSTALL_PAGES="$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageM10),$(PageDB)"
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageM10),$(PageDB)"
}

CustomParseDBConf()
{
	:
}

CustomGetDBName()
{
	:
}

CustomGetDBUser()
{
	:
}

CustomGetDBPass()
{
	:
}

CustomPageActivate()
{
	:
}

quote_json() {
	sed -e 's|\\|\\\\|g' -e 's|\"|\\\"|g'
}

#!/bin/bash
# Copyright (c) 2000-2017 Synology Inc. All rights reserved.

PKG_NAME="GLPI"
PKG_DIR="glpi"
WEBSITE_ROOT="/var/services/web/$PKG_DIR"
CONF_FILE="config/config_db.php"
MIGRATE_DB_VERSION="0112"
INIT_DB_NAME="glpi"
INIT_DB_USER="glpi_user"
INFO_FILE="/usr/syno/etc/packages/$PKG_NAME/$PKG_DIR.conf"

CustomParseDBConf()
{
	local path="$1"
	local db_info="$2"
	local grep_info="$3"
	local info_output=$(CustomGetValueFromMetaFile "$db_info")

	if [ -z "$info_output" ] && [ -s "$path/$CONF_FILE" ]; then
		info_output=$(grep "$grep_info" "$path/$CONF_FILE" | cut -d\' -f2)
	fi

	echo "$info_output"
}

CustomGetDBName()
{
	CustomParseDBConf "$1" "db_name" "dbdefault"
}

CustomGetDBUser()
{
	CustomParseDBConf "$1" "db_user" "dbuser"
}

CustomGetDBPass()
{
	CustomParseDBConf "$1" "db_pass" "dbpassword"
}
wizard_db_settings="GLPI-database instellen"
wizard_db_name_desc="Voer de databasenaam voor de GLPI-database in.   "
wizard_db_name_label="Databasenaam"
wizard_m10_desc="Voer de gebruikersgegevens van de administrator van MariaDB 10 in om door te gaan met de GLPI-database-instellingen."
wizard_admin_acc="Account"
wizard_admin_pass="Wachtwoord"
wizard_set_db_desc="Gebruik bestaande/nieuwe gegevens om een nieuwe exclusieve database-account voor GLPI te maken."
wizard_set_data_title="GLPI instellen"
wizard_found_backup="Pakket gereserveerde gegevens niet compatibel"
wizard_warn_data_backup_deprecated="De gereserveerde gegevens van dit pakket in uw systeem zijn niet compatibel met deze versie.<br>Als u deze versie installeert, worden de gereserveerde gegevens verwijderd.<br>Als u de gereserveerde gegevens wilt behouden, installeert u het pakket van dezelfde versie als uw vorige installatie. (Vorige versie: {prev_version})"
wizard_db_user_account_desc="Databasegebruikersaccount"
wizard_db_user_password_desc="Databasegebruikerwachtwoord"
wizard_migrate_note="Alleen de laatste versie van GLPI ondersteunt MariaDB 10.<br>Het systeem heeft een bestaande MariaDB 5-database gedetecteerd.<br>In de volgende stap wordt uw database van MariaDB 5 naar MariaDB 10 gemigreerd.<br><br>Voer de gebruikersgegevens van de administrator van MariaDB 5 om door te gaan met de installatie."
wizard_migrate_title="GLPI-database migreren"
wizard_remove_msql_title="GLPI-database verwijderen"
wizard_remove_msql_desc="Bij verwijdering van de GLPI-database worden alle gegevens verwijderd."
wizard_msql_password_desc_remove="Voer de gegevens van de databaseadministrator in om de GLPI-database te verwijderen."
wizard_admin_acc="Account"
wizard_admin_pass="Wachtwoord"
wizard_unable_to_upgrade_title="Kan niet bijwerken naar deze versie"
wizard_upgrade_from_prev_release_required_desc="Voordat u het pakket bijwerkt naar deze versie, moet u het bijwerken naar de <a href=\"{1}\" target=\"_blank\">voorgaande versie</a>."
PageUninst()
{
cat << EOF
{
	"step_title": "$wizard_remove_msql_title",
	"items": [{
		"type": "multiselect",
		"subitems": [{
			"key": "pkgwizard_remove_mysql",
			"defaultValue": true,
			"hidden": true
		}]
	}, {
		"type": "textfield",
		"desc": "$wizard_msql_password_desc_remove",
		"subitems": [{
			"key": "wizard_m10_acc",
			"desc": "$wizard_admin_acc",
			"defaultValue": "root"
		}]
	}, {
		"type": "password",
		"subitems": [{
			"indent": 1,
			"key": "wizard_m10_pass",
			"desc": "$wizard_admin_pass"
		}]
	}]
}
EOF
}
main()
{
	local uninst_page="$(PageUninst)"
	echo "[$uninst_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
